@@ -314,7 +314,7 @@ class Pickings(Enviopack):
     url = "{base_url}{base_path}".format(base_url=self.base_request_url, base_path=self.base_request_path)
     response = requests.post(url, params={'access_token':self.auth.access_token},json=params)
     self.raw_response = response
-    print(response.request.body)
+    self.raw_request = response.request
     respjson = response.json()
     self.response = respjson
     self.id = respjson.get('id',False)
